#[non_exhaustive]pub enum RootError {
NotFinite {
x: f64,
},
NotBracketed,
Tolerance {
tolerance: f64,
},
NotConverged,
}Expand description
Why find_root found no root.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFinite
The function or an end is not finite at x.
NotBracketed
The ends have the same strict sign.
Tolerance
The tolerance is negative or not a number.
NotConverged
The bracket didn’t shrink to the tolerance within the iteration limit.