#[non_exhaustive]pub enum Method {
DormandPrince54(Adaptive),
Rk4 {
step_s: f64,
},
}Expand description
The integration method.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DormandPrince54(Adaptive)
Adaptive Dormand–Prince 5(4) with error control and fourth-order dense output.
Rk4
Classical RK4 with a fixed step, shortened only to land on a stop time or an event.
Implementations
Sourceimpl Method
impl Method
Sourcepub fn validate(&self) -> Result<(), SettingsError>
pub fn validate(&self) -> Result<(), SettingsError>
Checks that tolerances and steps are finite and positive.
Errors
SettingsError naming the first bad setting.