issue_warnings

Function issue_warnings 

pub fn issue_warnings<'a>(
    parts: impl IntoIterator<Item = (&'a str, &'a Part)>,
    max_mach: Option<Peak>,
) -> Vec<IssueWarning>
The issues a flight meets: one whose top Mach number is max_mach, of a rocket whose parts are parts, each an id and its part, flown on hpr’s own drag. In KnownIssue’s order, each listing the parts that meet its condition. A flight with no top Mach number meets none.