pub struct BodySample {
pub time_s: f64,
pub cg_enu_m: DVec3,
pub cg_velocity_enu_m_s: DVec3,
pub height_above_ground_m: f64,
pub vertical_speed_m_s: f64,
pub airspeed_m_s: f64,
pub recovery_drag_area_m2: f64,
pub mass_kg: f64,
}Expand description
One separated body at an instant of its descent.
Fields
time_s: f64Time since launch, s.
cg_enu_m: DVec3Its center of mass in the launch frame, m.
cg_velocity_enu_m_s: DVec3That point’s velocity relative to the launch frame, m/s.
height_above_ground_m: f64Its center of mass’s ellipsoidal height above the launch site, m.
vertical_speed_m_s: f64The rate of that height, m/s.
airspeed_m_s: f64Its airspeed, m/s.
recovery_drag_area_m2: f64The drag area C_D S of its open devices, m².
mass_kg: f64Its mass, kg.